@@ -42,7 +42,8 @@ from gateways.common.cs18_api_responses import (
     ServiceResponse,
     BlueprintServiceResponse,
     LaunchingProgress, LaunchingProgressStep, CloudAccountInSpaceResponse, CloudAccountConnectivityResponse,
-    CloudAccountSubnetsResponse)
+    CloudAccountInfraSetResponse, CloudAccountSubnetsResponse, RegionResponse, GetImagesResponse,
+    VerifyCloudProviderResponse, VerifyCloudProviderResourceResponse)
 
 
 class Converters:
@@ -256,13 +257,16 @@ class Converters:
             return None
 
         return CloudAccountConnectivityResponse(
-            virtual_network=conn.get("virtual_network"),
-            subnets=CloudAccountSubnetsResponse(
-                gateway_subnet=conn["subnets"].get("gateway_subnet"),
-                management_subnet=conn["subnets"].get("management_subnet"),
-                application_subnets=conn["subnets"].get("application_subnets")
-            ) if "subnets" in conn else None
-        )
+            existing_infra=conn.get("existing_infra"),
+            existing_infra_sets=[CloudAccountInfraSetResponse(
+                region=infra_set["region"],
+                virtual_network=infra_set["virtual_network"],
+                subnets=CloudAccountSubnetsResponse(
+                    gateway_subnet=infra_set["subnets"].get("gateway_subnet"),
+                    management_subnet=infra_set["subnets"].get("management_subnet"),
+                    application_subnets=infra_set["subnets"].get("application_subnets")
+                ) if "subnets" in infra_set else None) for infra_set in conn.get("existing_infra_sets")]
+            if "existing_infra_sets" in conn else None)
 
     @staticmethod
     def _create_blueprint_input_response(
@@ -775,3 +779,33 @@ class Converters:
             succeeded=step['succeeded'],
             failed=step['failed'],
             status=step['status'])
+
+    @staticmethod
+    def create_space_cloud_account_regions_response(region: dict) -> RegionResponse:
+        return RegionResponse(region["id"], region["name"])
+
+    @staticmethod
+    def get_image_response(images: dict):
+        return GetImagesResponse(images['image_id'], images['image_name'])
+
+    @staticmethod
+    def _create_resources_summary_response(resources_summary: dict) -> List[VerifyCloudProviderResourceResponse]:
+        resources = []
+        if resources_summary:
+            for resource in resources_summary:
+                resources.append(
+                    VerifyCloudProviderResourceResponse(
+                        resource_type=resource["resource_type"],
+                        resource_name=resource["resource_name"],
+                        resource_id=resource["resource_id"],
+                        resource_status=resource["resource_status"]
+                    )
+                )
+        return resources
+
+    @staticmethod
+    def create_verify_response(verify: dict) -> VerifyCloudProviderResponse:
+        return VerifyCloudProviderResponse(
+            success=verify["success"],
+            resources_summary=Converters._create_resources_summary_response(verify["resources_summary"]),
+        )
