@@ -707,14 +707,24 @@ class CloudAccountSubnetsResponse:
         self.application_subnets = application_subnets
 
 
-class CloudAccountConnectivityResponse:
+class CloudAccountInfraSetResponse:
     def __init__(self,
+                 region: str,
                  virtual_network: str,
                  subnets: CloudAccountSubnetsResponse):
+        self.region = region
         self.virtual_network = virtual_network
         self.subnets = subnets
 
 
+class CloudAccountConnectivityResponse:
+    def __init__(self,
+                 existing_infra: bool,
+                 existing_infra_sets: List[CloudAccountInfraSetResponse]):
+        self.existing_infra = existing_infra
+        self.existing_infra_sets = existing_infra_sets
+
+
 class CloudAccountInSpaceResponse:
     def __init__(
             self,
@@ -814,3 +824,38 @@ class UserForAllUsersResponse:
         self.account_role = account_role
         self.has_access_to_all_spaces = has_access_to_all_spaces
         self.member_in_spaces = member_in_spaces
+
+
+class RegionResponse:
+    def __init__(
+            self,
+            region_id: str,
+            region_name: str
+    ):
+        self.region_id = region_id
+        self.region_name = region_name
+
+
+class GetImagesResponse:
+    def __init__(self, image_id: str, image_name: str):
+        self.image_id = image_id
+        self.image_name = image_name
+
+
+class VerifyCloudProviderResourceResponse:
+    def __init__(self,
+                 resource_type: str,
+                 resource_name: str,
+                 resource_id: str = None,
+                 resource_status: str = None):
+        self.resource_type = resource_type
+        self.resource_name = resource_name
+        self.resource_id = resource_id
+        self.resource_status = resource_status
+
+
+class VerifyCloudProviderResponse:
+    def __init__(self, success: bool,
+                 resources_summary: List[VerifyCloudProviderResourceResponse] = None):
+        self.success = success
+        self.resources_summary = resources_summary
